﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Core;
using System.IO;

namespace Translate
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
            combTS.SelectedIndex = 0;
            MakePanelsEvenSizes();
            SizeChanged += new EventHandler(Form1_SizeChanged);
        }

        bool SimplifiedToTraditional
        {
            get
            {
                return combTS.SelectedIndex == 0;
            }
        }

        void MakePanelsEvenSizes()
        {
            int totalPanelHeight = splitContainer1.Panel1.Height + splitContainer1.Panel2.Height;
            splitContainer1.SplitterDistance = totalPanelHeight / 2;
        }

        void Convert()
        {
            textBox2.Text = SimplifiedToTraditional ? WordFunctions.CHS2CHT(textBox1.Text) : WordFunctions.CHT2CHS(textBox1.Text);
        }

        void ConvertAndCopyToClipboard()
        {
            string r = SimplifiedToTraditional ? WordFunctions.CHS2CHT(Clipboard.GetText()) : WordFunctions.CHT2CHS(Clipboard.GetText()); 
            Clipboard.SetText(r);
            textBox2.Text = r;
        }

        void ConvertFiles()
        {
            using (OpenFileDialog dialog = new OpenFileDialog())
            {
                dialog.Multiselect = true;

                if (dialog.ShowDialog(this) != DialogResult.OK)
                {
                    return;
                }

                string targetDirectory;

                using (FolderBrowserDialog dirDialog = new FolderBrowserDialog())
                {
                    if (dirDialog.ShowDialog(this) != DialogResult.OK)
                    {
                        return;
                    }

                    targetDirectory = dirDialog.SelectedPath;
                }

                foreach (string fileName in dialog.FileNames)
                {
                    using (StreamReader reader = new StreamReader(fileName))
                    {
                        string s = reader.ReadToEnd();
                        reader.Close();
                        using (StreamWriter writer = new StreamWriter(targetDirectory+ "\\"+ Path.GetFileName(fileName)))
                        {
                            string t = SimplifiedToTraditional ? WordFunctions.CHS2CHT(s) : WordFunctions.CHT2CHS(s);
                            writer.Write(t);
                            writer.Close();
                        }
                    }

                }

            }
        }

        const string wordFilter = "Word Document|*.doc|Word 2007 Document|*.docx";

        void ConvertWordDocument()
        {
            using (OpenFileDialog openDialog = new OpenFileDialog())
            {
                openDialog.Filter = wordFilter ;
                if (openDialog.ShowDialog(this) != DialogResult.OK)
                {
                    return;
                }

                string sourceFileName = openDialog.FileName;

                string targetFileName;

                using (SaveFileDialog saveDialog = new SaveFileDialog())
                {
                    saveDialog.Filter = wordFilter;
                    if (saveDialog.ShowDialog(this) != DialogResult.OK)
                    {
                        return;
                    }
                    targetFileName = saveDialog.FileName;
                }

                WordFunctions.ConvertWordDocument(sourceFileName, targetFileName, SimplifiedToTraditional);
            }
        }

        void Form1_SizeChanged(object sender, EventArgs e)
        {
            MakePanelsEvenSizes();
        }

        private void Form1_FormClosed(object sender, FormClosedEventArgs e)
        {
            WordFunctions.CloseWordApplication();
        }

        private void ljlkjToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ConvertAndCopyToClipboard();
        }

        private void fdsdfToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Convert();
        }

        private void filesToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ConvertFiles();
        }

        private void directoryToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ConvertWordDocument();
        }

    }
}
